@@ -992,7 +992,7 @@ def R_matrix(N1,N2,N3,tot_atoms_uc,R0, H):
             found_min_dist = np.argwhere(dist_Scells == np.min(dist_Scells, axis=0))
             found_min_dist_0 = found_min_dist[0]
             row.append((Scells[found_min_dist_0,j,:] - atom_origin).flatten())
-        row = np.array(row)
+        row = np.array(row, dtype=object)
         repeated_row = np.tile(row.flatten(),(3,1))
         R_matrix_old[count:count+3,:] = repeated_row
         # R_matrix_new[count_new] = 
@@ -1022,7 +1022,7 @@ def R_matrix_multiplicity(N1,N2,N3,tot_atoms_uc,R0, H, tolerance=1.01):
             min_dist = np.min(dist_Scells, axis=0)
             found_min_dist = np.argwhere( dist_Scells <= tolerance*min_dist)
             row.append(Scells[found_min_dist,j,:] - atom_origin)
-        row = np.array(row)
+        row = np.array(row, dtype=object)
         R_matrix_new.append(row)
     
     return R_matrix_new# *0.529177249
